@@ -1,5 +1,6 @@
 import pickle
 import string
+from pathlib import Path
 
 
 class DeasciifierBuiltin:
@@ -42,18 +43,9 @@ class DeasciifierBuiltin:
           Toggles the accent of the character.
     """
 
-    def get_path():
-        """
-        This function returns the path to the parent directory of the `mintlemon/` folder.
+    PATH = str(Path(__file__).parent.parent / "data")
 
-        Returns:
-        -------
-        str:
-            Path to the parent directory of the `mintlemon/` folder.
-        """
-        return __file__[: __file__.find("mintlemon-turkish-nlp/") + len("mintlemon-turkish-nlp/")]
-
-    ascii_pickle_path = get_path() + "data/ascii_to_str_dict.pickle"
+    ascii_pickle_path = PATH + "/ascii_to_str_dict.pickle"
 
     with open(ascii_pickle_path, "rb") as file:
         turkish_pattern_table = pickle.load(file)
