@@ -2,10 +2,10 @@ import re
 from typing import List
 from pathlib import Path
 
-PATH = str(Path(__file__).parent.parent.parent / "data")
-
 
 class SentenceSplitter:
+
+    PATH = str(Path(__file__).parent.parent / "data")
     """
     SentenceSplitter is a class used for splitting a text into sentences by considering `Turkish non-breaking prefixes <https://github.com/tnltk/tnltk/blob/main/resources/TR_non_breaking_prefixes.txt>`_
 
@@ -48,3 +48,5 @@ class SentenceSplitter:
         sentences = re.split(r"(?<=[.!?])\s", text)
 
         return sentences
+
+
